@@ -2,6 +2,14 @@
 }, function(program) {
   var output;
   try {
+    delete this.console;
+    delete this.setTimeout;
+    delete this.setInterval;
+    delete this.clearTimeout;
+    delete this.clearInterval;
+    delete this.setImmediate;
+    delete this.clearImmediate;
+
     result = program();
     if (typeof result == 'undefined' && result !== null) {
       print('["ok"]');
