@@ -5,6 +5,7 @@ require "json"
 
 begin
   require "execjs"
+  ExecJS.runtime
 rescue ExecJS::RuntimeUnavailable => e
   warn e
   exit 2
@@ -56,6 +57,16 @@ class TestExecJS < Test
     assert_equal 2, context.call("(function(bar) { return foo + bar })", 1)
   end
 
+  def test_call_with_env_file
+    Dir.mktmpdir do |dir|
+      Dir.chdir(dir) do
+        # Bun prints on STDOUT when loading .env files
+        File.write(".env", "FOO=BAR")
+        assert_equal 2, ExecJS.eval("1 + 1")
+      end
+    end
+  end
+
   def test_call_with_this
     # Known bug: https://github.com/cowboyd/therubyrhino/issues/39
     skip if ExecJS.runtime.is_a?(ExecJS::RubyRhinoRuntime)
@@ -156,7 +167,7 @@ class TestExecJS < Test
       assert_output value, ExecJS.eval("#{json_value}")
     end
 
-    define_method("test_strinigfy_value_#{index}") do
+    define_method("test_stringify_value_#{index}") do
       context = ExecJS.compile("function json(obj) { return JSON.stringify(obj); }")
       assert_output json_value, context.call("json", value)
     end
@@ -167,6 +178,16 @@ class TestExecJS < Test
     end
   end
 
+  def test_symbol
+    context = ExecJS.compile("function echo(test) { return test; }")
+    assert_equal "symbol", context.call("echo", :symbol)
+    assert_equal ["symbol"], context.call("echo", [:symbol])
+    assert_equal({"key" => "value"}, context.call("echo", {key: :value}))
+
+    context = ExecJS.compile("function myslice(str) { return str.slice(1); }")
+    assert_equal "ymbol", context.call("myslice", :symbol)
+  end
+
   def test_additional_options
     assert ExecJS.eval("true", :foo => true)
     assert ExecJS.exec("return true", :foo => true)
@@ -286,6 +307,9 @@ class TestExecJS < Test
   end
 
   def test_timers_are_undefined
+    # See Bug https://github.com/oven-sh/bun/issues/4806
+    skip if ENV["EXECJS_RUNTIME"] == "Bun"
+
     assert ExecJS.eval("typeof setTimeout == 'undefined'")
     assert ExecJS.eval("typeof setInterval == 'undefined'")
     assert ExecJS.eval("typeof clearTimeout == 'undefined'")
@@ -317,7 +341,7 @@ class TestExecJS < Test
       flunk
     rescue ExecJS::RuntimeError => e
       assert e
-      assert e.backtrace[0].include?("(execjs):1"), e.backtrace.join("\n")
+      assert e.backtrace.join("\n").include?("(execjs):")
     end
   end
 
@@ -327,7 +351,7 @@ class TestExecJS < Test
       flunk
     rescue ExecJS::RuntimeError => e
       assert e
-      assert e.backtrace[0].include?("(execjs):1"), e.backtrace.join("\n")
+      assert e.backtrace.join("\n").include?("(execjs):")
     end
   end
 
@@ -337,7 +361,7 @@ class TestExecJS < Test
       flunk
     rescue ExecJS::RuntimeError => e
       assert e
-      assert e.backtrace[0].include?("(execjs):1"), e.backtrace.join("\n")
+      assert e.backtrace[0].include?("(execjs):"), e.backtrace.join("\n")
     end
   end
 
@@ -347,7 +371,7 @@ class TestExecJS < Test
       flunk
     rescue ExecJS::ProgramError => e
       assert e
-      assert e.backtrace[0].include?("(execjs):1"), e.backtrace.join("\n")
+      assert e.backtrace.join("\n").include?("(execjs):")
     end
   end
 
@@ -357,7 +381,7 @@ class TestExecJS < Test
       flunk
     rescue ExecJS::ProgramError => e
       assert e
-      assert e.backtrace[0].include?("(execjs):1"), e.backtrace.join("\n")
+      assert e.backtrace.join("\n").include?("(execjs):")
     end
   end
 
@@ -367,7 +391,7 @@ class TestExecJS < Test
       flunk
     rescue ExecJS::ProgramError => e
       assert e
-      assert e.backtrace[0].include?("(execjs):1"), e.backtrace.join("\n")
+      assert e.backtrace.join("\n").include?("(execjs):")
     end
   end
 
@@ -427,6 +451,15 @@ class TestExecJS < Test
       context.call("uglify", "function foo(bar) {\n  return bar;\n}")
   end
 
+  def test_async_bun
+    skip unless ENV["EXECJS_RUNTIME"] == "Bun"
+    source = <<-JS
+      async function testAsync() { return (await new Promise((resolve) => { resolve("it works!") } )) }
+    JS
+    context = ExecJS.compile(source)
+    assert_equal "it works!", context.call("testAsync")
+  end
+
   private
 
     def assert_output(expected, actual)
